@@ -1,16 +1,11 @@
 {-# LANGUAGE OverloadedStrings, NoMonomorphismRestriction #-}
-module WaiAppStaticTest (specs) where 
+module WaiAppStaticTest (spec) where
 
 import Network.Wai.Application.Static
 
-import Test.Hspec.Monadic
-import Test.Hspec.QuickCheck
-import Test.Hspec.HUnit ()
-import Test.HUnit ((@?=))
-import Data.List (isInfixOf)
+import Test.Hspec
 import qualified Data.ByteString.Char8 as S8
 -- import qualified Data.ByteString.Lazy.Char8 as L8
-import qualified Data.Text as T
 import System.PosixCompat.Files (getFileStatus, modificationTime)
 
 import Network.HTTP.Date
@@ -21,26 +16,27 @@ import Network.Wai
 import Network.Wai.Test
 
 import Control.Monad.IO.Class (liftIO)
+import Network.Mime
 
 defRequest :: Request
 defRequest = defaultRequest
 
-specs :: Specs
-specs = do
-  let webApp = flip runSession $ staticApp defaultWebAppSettings  {ssFolder = fileSystemLookup "test"}
-  let fileServerApp = flip runSession $ staticApp defaultFileServerSettings  {ssFolder = fileSystemLookup "test"}
+spec :: Spec
+spec = do
+  let webApp = flip runSession $ staticApp $ defaultWebAppSettings "test"
+  let fileServerApp = flip runSession $ staticApp $ defaultFileServerSettings "test"
 
   let etag = "1B2M2Y8AsgTpgAmY7PhCfg=="
   let file = "a/b"
   let statFile = setRawPathInfo defRequest file
 
-  describe "Pieces: pathFromPieces" $ do
-    it "converts to a file path" $
-      (pathFromPieces "prefix" ["a", "bc"]) @?= "prefix/a/bc"
-
-    prop "each piece is in file path" $ \piecesS ->
-      let pieces = map (FilePath . T.pack) piecesS
-      in  all (\p -> ("/" ++ p) `isInfixOf` (T.unpack $ unFilePath $ pathFromPieces "root" $ pieces)) piecesS
+  describe "mime types" $ do
+    it "fileNameExtensions" $
+        fileNameExtensions "foo.tar.gz" `shouldBe` ["tar.gz", "gz"]
+    it "handles multi-extensions" $
+        defaultMimeLookup "foo.tar.gz" `shouldBe` "application/x-tgz"
+    it "defaults correctly" $
+        defaultMimeLookup "foo.unknown" `shouldBe` "application/octet-stream"
 
   describe "webApp" $ do
     it "403 for unsafe paths" $ webApp $
@@ -62,8 +58,8 @@ specs = do
       assertStatus 301 req
       assertHeader "Location" "../../a/b/c" req
 
-    let absoluteApp = flip runSession $ staticApp $ defaultWebAppSettings {
-          ssFolder = fileSystemLookup "test", ssMkRedirect = \_ u -> S8.append "http://www.example.com" u
+    let absoluteApp = flip runSession $ staticApp $ (defaultWebAppSettings "test") {
+          ssMkRedirect = \_ u -> S8.append "http://www.example.com" u
         }
     it "301 redirect when multiple slashes" $ absoluteApp $
       flip mapM_ ["/a//b/c", "a//b/c"] $ \path -> do
@@ -75,22 +71,13 @@ specs = do
     it "200 and etag when no etag query parameters" $ webApp $ do
       req <- request statFile
       assertStatus 200 req
-      assertNoHeader "Cache-Control" req
       assertHeader "ETag" etag req
       assertNoHeader "Last-Modified" req
 
-    it "200 when no cache headers and bad cache query string" $ webApp $ do
-      flip mapM_ [Just "cached", Nothing] $ \badETag -> do
-        req <- request statFile { queryString = [("etag", badETag)] }
-        assertStatus 301 req
-        assertHeader "Location" "../a/b?etag=1B2M2Y8AsgTpgAmY7PhCfg%3D%3D" req
-        assertNoHeader "Cache-Control" req
-        assertNoHeader "Last-Modified" req
-
     it "Cache-Control set when etag parameter is correct" $ webApp $ do
       req <- request statFile { queryString = [("etag", Just etag)] }
       assertStatus 200 req
-      assertHeader "Cache-Control" "max-age=31536000" req
+      assertHeader "Cache-Control" "public, max-age=31536000" req
       assertNoHeader "Last-Modified" req
 
     it "200 when invalid in-none-match sent" $ webApp $
@@ -125,7 +112,6 @@ specs = do
           requestHeaders = [("If-Modified-Since", badDate)]
         }
         assertStatus 200 req
-        assertNoHeader "Cache-Control" req
         fdate <- fileDate
         assertHeader "Last-Modified" fdate req
 
