@@ -1,5 +1,6 @@
 import WaiAppStaticTest (spec)
+import WaiAppEmbeddedTest (embSpec)
 import Test.Hspec.Monadic
 
 main :: IO ()
-main = hspec spec
+main = hspec $ spec >> embSpec
